import os
import yaml

CONFIG_PATH = os.path.join(os.path.expanduser('~'), '.config/cceyes/config.yaml')

# Load the config
if os.path.exists(CONFIG_PATH):
    with open(CONFIG_PATH, 'r') as configfile:
        config = yaml.safe_load(configfile)
else:
    config = {}

if 'key' in config.get('api', {}):
    headers = {'X-Api-Key': config['api']['key']}
else:
    headers = {}


def init():
    # create CONFIG_PATH if not exists
    if not os.path.exists(os.path.dirname(CONFIG_PATH)):
        os.makedirs(os.path.dirname(CONFIG_PATH))

    # if api.host is not set in config file, set it to https://api.cceyes.eu
    default = config.setdefault('api', {})
    default.setdefault('host', 'https://api.cceyes.eu')

    # Write the config back to the file
    with open(CONFIG_PATH, 'w') as configfile:
        yaml.safe_dump(config, configfile, default_flow_style=False)


def set_config(parent, key, value):
    config.setdefault(parent, {})[key] = value

    # Write the config back to the file
    with open(CONFIG_PATH, 'w') as configfile:
        yaml.safe_dump(config, configfile, default_flow_style=False)


def get_config(parent, key):
    # if the config value is not set, throw an error
    if parent not in config or key not in config[parent]:
        raise Exception(f"Config value {parent}.{key} is not set")

    return config[parent][key]



import requests
import json
from . import config
from cceyes.models import Production


def datasets():
    url = config.get_config('api', 'host') + "/providers/datasets"
    response = requests.request("GET", url, headers=config.headers)

    return response


def stats():
    url = config.get_config('api', 'host') + "/providers/stats"
    response = requests.request("GET", url, headers=config.headers)

    return response


def upsert(productions: list[Production]):
    url = config.get_config('api', 'host') + "/productions"

    # go through every item in the list and convert to JSON
    for i, production in enumerate(productions):
        productions[i] = production.dict()

    response = requests.request("POST", url, headers=config.headers, json=productions)

    return response



from pydantic import BaseModel, Field
from enum import Enum
from typing import Optional


class StatusEnum(str, Enum):
    Concept = "Concept"
    InDevelopment = "In Development"
    PostProduction = "Post-Production"
    Completed = "Completed"
    Released = "Released"
    OnHiatus = "On Hiatus"
    Cancelled = "Cancelled"
    Archived = "Archived"


class ProductionReviews(BaseModel):
    rating: float = Field(
        ..., title="Average rating from 0 to 10 from audiences or critics", ge=0, le=10
    )
    count: int = Field(0, title="Number of reviews", ge=0)
    popularity: float = Field(
        ...,
        title="Rating from 0 (smallest audience size) to 10 (largest audience size)",
        ge=0,
        le=10,
    )

    class Config:
        json_schema_extra = {"example": {"rating": 7.5, "count": 10, "popularity": 8.5}}


class ProductionStatus(BaseModel):
    current_status: StatusEnum
    last_updated: str
    notes: Optional[str]

    class Config:
        json_schema_extra = {
            "example": {
                "current_status": "In Development",
                "last_updated": "2023-08-14",
                "notes": "The script is in its final stages, expected to move to post-production by September.",
            }
        }


class ProductionExtra(BaseModel):
    model_config = {"extra": "allow"}


class ProductionBaseMeta(BaseModel):
    id: str


class ProductionMeta(ProductionBaseMeta):
    title: str
    image: str | None = None
    status: ProductionStatus | None = None
    reviews: ProductionReviews | None = None
    extra: ProductionExtra | None = None

    def model_dump(self, **kwargs):
        return super().model_dump(**kwargs)


class ProductionDataset(BaseModel):
    type: str
    provider: str


class BaseProduction(BaseModel):
    title: str = Field(..., title="Production title", max_length=255)
    content: str = Field(..., title="Production content", max_length=1000)
    dataset: ProductionDataset = Field(..., title="Production dataset")
    meta: ProductionMeta = Field(..., title="Production meta")

    class Config:
        json_schema_extra = {
            "example": {
                "title": "Lost in Time",
                "content": "Dr. Clara Maxwell, a brilliant but eccentric physicist, stumbles upon a groundbreaking discovery - a watch-like device that can transport the wearer through time. When her teenage son, Jack, accidentally activates the device, he is flung into different eras every time he falls asleep. In every episode, Clara, her faithful assistant Reuben, and Jack’s best friend Lily must decipher clues left by Jack about his location in time. As they race against the clock, they must navigate the perils of history, while trying to bring back Jack, one era at a time.",
                "dataset": {"type": "TV Series", "provider": "BetaSeries"},
                "meta": {
                    "id": 1,
                    "title": "Lost in Time",
                    "image": "https://placehold.co/300x400",
                },
            }
        }


class Production(BaseProduction):
    id: int = Field(None, title="Production ID", examples=[1])
    score: Optional[float] = Field(None, title="Relevance score", examples=[0.5])



import requests
import logging
import utils
import cceyes
from cceyes.models import Production, ProductionDataset, ProductionMeta
from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn, TimeRemainingColumn, TimeElapsedColumn
from rich.logging import RichHandler

FORMAT = "%(message)s"
logging.basicConfig(
    level="DEBUG", format=FORMAT, datefmt="[%X]", handlers=[RichHandler()]
)


def find_popular_shows(number=100):
    start = 0
    all_tv_shows = []

    while start < number:
        url = f"https://api.betaseries.com/shows/list?limit=100&order=popularity&locale=en&start={start}"
        response = requests.get(url, headers=utils.headers)
        tv_shows = response.json()['shows']

        if not tv_shows:
            break

        if number < 100:
            tv_shows = tv_shows[:number]

        all_tv_shows.extend(tv_shows)
        start += 100

    return all_tv_shows


def create_meta(tv_show):
    # Fetch the TV series details
    return {
        'id': str(tv_show['id']),
        'title': tv_show['title'],
        'image': tv_show['images']['poster'],
    }


def create_content(tv_show):
    # Fetch the TV series details including the synopsis
    content = f"{tv_show['title']}: {tv_show['description']}"

    # Limit to 1000 characters
    return content[:1000]


def main():
    log = logging.getLogger("rich")
    log.info(cceyes.providers.datasets().text)

    with Progress(
        SpinnerColumn(),
        TimeElapsedColumn(),
        BarColumn(),
        TimeRemainingColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:
        global_progress = progress.add_task("[red]Fetching TV Series…")
        tv_shows = find_popular_shows(1000)
        progress.update(global_progress, total=len(tv_shows))
        productions = []

        for tv_show in tv_shows:
            log.debug(tv_show['title'])

            progress.update(global_progress, advance=0.1, description=tv_show['title'])

            meta = create_meta(tv_show)
            progress.update(global_progress, advance=0.2)

            content = create_content(tv_show)
            progress.update(global_progress, advance=0.2)

            # Add the production to the list
            productions.append(Production(
                title=meta["title"],
                content=content,
                dataset=ProductionDataset(
                    type='TV Series',
                    provider='BetaSeries',
                ),
                meta=ProductionMeta(
                    id=meta["id"],
                    title=meta["title"],
                    image=meta['image'],
                ),
            ))

            progress.update(global_progress, advance=0.2)

            # If we have 100 productions, send them to the API
            if len(productions) == 100:
                response = cceyes.providers.upsert(productions)
                log.debug(response.text)

                progress.update(global_progress, advance=0.3*10)
                productions = []

        response = cceyes.providers.upsert(productions)
        log.debug(response.text)

        progress.update(global_progress, advance=len(tv_shows))


if __name__ == "__main__":
    main()



import requests
import logging
import cceyes
import cceyes.config as config
from cceyes.models import Production, ProductionDataset, ProductionMeta
from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn, TimeRemainingColumn, TimeElapsedColumn
from rich.logging import RichHandler

FORMAT = "%(message)s"
logging.basicConfig(
    level="DEBUG", format=FORMAT, datefmt="[%X]", handlers=[RichHandler()]
)


def find_popular_books(num_books=40, start_index=0):
    key = config.get_config('google', 'key')
    base_url = f"https://www.googleapis.com/books/v1/volumes?key={key}"
    params = {
        "q": "subject:fiction",  # You can modify the query to suit your needs
        "orderBy": "newest",
        "maxResults": 40,
        "langRestrict": "en",
        "startIndex": start_index,
    }

    books = []

    while start_index < num_books:
        params['startIndex'] = start_index
        response = requests.get(base_url, params=params)
        data = response.json()
        logging.debug(data)

        popular_books = data.get("items", [])

        for book in popular_books:
            volume_info = book.get("volumeInfo", {})

            books.append({
                "id": book["id"],
                "title": volume_info.get("title", "N/A"),
                "authors": ", ".join(volume_info.get("authors", ["N/A"])),
                "publish_date": volume_info.get("publishedDate", "N/A"),
                "description": volume_info.get("description", "N/A"),
                "cover": volume_info.get("imageLinks", {}).get("thumbnail", ""),
            })

        start_index += 40

    return books


def create_meta(book):
    # Fetch the book details
    return {
        'id': book['id'],
        'title': book['title'],
        'image': book['cover'],
    }


def create_content(book):
    # Fetch the TV series details including the synopsis
    content = f"{book['title']}: {book['description']}"

    # Limit to 1000 characters
    return content[:1000]


def main():
    log = logging.getLogger("rich")
    log.info(cceyes.providers.datasets().text)

    with Progress(
        SpinnerColumn(),
        TimeElapsedColumn(),
        BarColumn(),
        TimeRemainingColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:
        global_progress = progress.add_task("[red]Fetching Books…")
        books = find_popular_books(1000, 0)
        progress.update(global_progress, total=len(books))
        productions = []
        logging.debug(books)

        for book in books:
            log.debug(book['title'])

            progress.update(global_progress, advance=0.1, description=book['title'])

            meta = create_meta(book)
            progress.update(global_progress, advance=0.2)

            content = create_content(book)
            progress.update(global_progress, advance=0.2)

            # Add the production to the list
            productions.append(Production(
                title=meta["title"],
                content=content,
                dataset=ProductionDataset(
                    type='Book',
                    provider='Google',
                ),
                meta=ProductionMeta(
                    id=meta["id"],
                    title=meta["title"],
                    image=meta['image'],
                ),
            ))

            progress.update(global_progress, advance=0.2)

            # If we have 30 productions, send them to the API
            if len(productions) == 30:
                response = cceyes.providers.upsert(productions)
                log.debug(response.text)

                progress.update(global_progress, advance=0.3*10)
                productions = []

        response = cceyes.providers.upsert(productions)
        log.debug(response.text)

        progress.update(global_progress, advance=len(books))


if __name__ == "__main__":
    main()



import requests
import logging
import cceyes
import pandas as pd
import cceyes.config as config
import cceyes.productions
import time
from cceyes.models import Production, ProductionDataset, ProductionMeta
from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn, TimeRemainingColumn, TimeElapsedColumn
from rich.logging import RichHandler


FORMAT = "%(message)s"
logging.basicConfig(
    level="DEBUG", format=FORMAT, datefmt="[%X]", handlers=[RichHandler()]
)


def find_popular_movies():
    url = "https://api.themoviedb.org/3/movie/popular"
    movies = []

    for page in range(51, 101):
        params = {'api_key': config.get_config('tmdb', 'key'), 'page': page}
        response = requests.get(url, params=params)

        if response.status_code != 200:
            logging.debug(f"Failed to get data for page {page}, status code: {response.status_code}")
            continue

        data = response.json()
        movies.extend(data['results'])

        # sleep
        time.sleep(1)

    return movies


def create_production(movie):
    production = Production(
        title=movie['title'],
        content=movie['overview'][:1000],
        dataset=ProductionDataset(
            type='Movie',
            provider='TMDB',
        ),
        meta=ProductionMeta(
            id=str(movie['id']),
            title=movie['title'],
            image=f"https://image.tmdb.org/t/p/original/{movie['poster_path']}",
        ),
    )

    return production


def main():
    log = logging.getLogger("rich")
    log.info(cceyes.providers.datasets().text)

    with Progress(
        SpinnerColumn(),
        TimeElapsedColumn(),
        BarColumn(),
        TimeRemainingColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:
        global_progress = progress.add_task("[red]Fetching Movies…")
        movies = find_popular_movies()
        progress.update(global_progress, total=len(movies))
        productions = []
        logging.debug(movies)

        for movie in movies:
            log.debug(movie['title'])

            progress.update(global_progress, advance=0.1, description=movie['title'])

            # Check if already exists
            # production = cceyes.productions.find(
            #    ProductionDataset(type='Movie', provider='TMDB'),
            #    ProductionMeta(id=str(movie['id']), title=movie['title'])
            # )

            progress.update(global_progress, advance=0.1)

            # if production:
            #    progress.update(global_progress, advance=0.8)
            #    continue

            # Create production
            production = create_production(movie)
            print(production)

            if production is not None:
                # Add the production to the list
                productions.append(production)

            progress.update(global_progress, advance=0.6)

            # If we have 30 productions, send them to the API
            if len(productions) == 30:
                response = cceyes.providers.upsert(productions)
                log.debug(response.text)

                progress.update(global_progress, advance=0.3*10)
                productions = []

        response = cceyes.providers.upsert(productions)
        log.debug(response.text)

        progress.update(global_progress, advance=len(movies))


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages
import sys
sys.path.insert(0, ".")  # noqa
import versioneer
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="cceyes",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    python_requires='>=3.6, <4',
    install_requires=[
        'requests',
        'typer',
        'PyYAML',
        'pydantic',
    ],
    entry_points={
        'console_scripts': [
            'cceyes=cceyes.main:app',
        ],
    },
)



import requests
import json
import sys
import typer
from . import providers, config as config_module

app = typer.Typer()


@app.callback()
def main():
    """
    CCEyes CLI
    """
    config_module.init()


@app.command()
def key():
    api_key = typer.prompt("Enter your API key", hide_input=True)
    config_module.set_config('api', 'key', api_key)

    print("API key saved!")


@app.command()
def config(
    parent: str = typer.Argument(..., help="Parent key"),
    key: str = typer.Argument(..., help="Key"),
    value: str = typer.Argument(..., help="Value"),
):
    """
    Set a config value
    """
    config_module.set_config(parent, key, value)

    print("Config value saved!")


@app.command()
def datasets():
    """
    Display datasets associated with the key
    """
    response = providers.datasets()

    print(response.text)


@app.command()
def stats():
    """
    Display datasets stats
    """
    response = providers.stats()

    print(response.text)


@app.command()
def upsert():
    """
    Upsert productions into the CCEyes database
    """
    response = providers.upsert(json.loads(sys.stdin.read()))

    print(response.text)


if __name__ == "__main__":
    app()



import requests
import logging
import cceyes
import pandas as pd
import cceyes.config as config
import cceyes.productions
import re
from cceyes.models import Production, ProductionDataset, ProductionMeta
from rich.progress import Progress, SpinnerColumn, TextColumn, BarColumn, TimeRemainingColumn, TimeElapsedColumn
from rich.logging import RichHandler


FORMAT = "%(message)s"
logging.basicConfig(
    level="DEBUG", format=FORMAT, datefmt="[%X]", handlers=[RichHandler()]
)


def find_popular_games():
    url = "https://steamspy.com/api.php"
    response = requests.get(url, params={"request": "all"})
    data = response.json()
    games = []

    steam_spy_all = pd.DataFrame.from_dict(data, orient='index')
    app_list = steam_spy_all[['appid', 'name']].sort_values('appid').reset_index(drop=True)

    for index, row in app_list.iterrows():
        games.append(row)

    return games


def parse_steam_request(appid, name):
    """Unique parser to handle data from Steam Store API.

    Returns : json formatted data (dict-like)
    """
    url = "https://store.steampowered.com/api/appdetails/"
    parameters = {"appids": appid}

    data = requests.get(url, params=parameters)
    json_data = data.json()

    data = {'name': name, 'steam_appid': appid}

    if json_data is not None:
        json_app_data = json_data[str(appid)]

        if json_app_data['success']:
            data = json_app_data['data']

    return data


def create_production(row):
    game = parse_steam_request(row['appid'], row['name'])

    if game.get('detailed_description'):
        description = re.sub('<[^<]+?>', '', game['detailed_description'])

        production = Production(
            title=game['name'],
            content=description[:1000],
            dataset=ProductionDataset(
                type='Game',
                provider='Steam',
            ),
            meta=ProductionMeta(
                id=str(row['appid']),
                title=row['name'],
                image=game['header_image'],
            ),
        )

        return production

    return None


def main():
    log = logging.getLogger("rich")
    log.info(cceyes.providers.datasets().text)

    with Progress(
        SpinnerColumn(),
        TimeElapsedColumn(),
        BarColumn(),
        TimeRemainingColumn(),
        TextColumn("[progress.description]{task.description}"),
        transient=True,
    ) as progress:
        global_progress = progress.add_task("[red]Fetching Games…")
        games = find_popular_games()
        progress.update(global_progress, total=len(games))
        productions = []
        logging.debug(games)

        for game in games:
            log.debug(game['name'])

            progress.update(global_progress, advance=0.1, description=game['name'])

            # Check if already exists
            production = cceyes.productions.find(
                ProductionDataset(type='Game', provider='Steam'),
                ProductionMeta(id=str(game['appid']), title=game['name'])
            )

            progress.update(global_progress, advance=0.1)

            if production:
                progress.update(global_progress, advance=0.8)
                continue

            # Create production
            production = create_production(game)
            print(production)

            if production is not None:
                # Add the production to the list
                productions.append(production)

            progress.update(global_progress, advance=0.6)

            # If we have 30 productions, send them to the API
            if len(productions) == 30:
                response = cceyes.providers.upsert(productions)
                log.debug(response.text)

                progress.update(global_progress, advance=0.3*10)
                productions = []

        response = cceyes.providers.upsert(productions)
        log.debug(response.text)

        progress.update(global_progress, advance=len(games))


if __name__ == "__main__":
    main()



import requests
import json
from . import config
from cceyes.models import Production, ProductionDataset, ProductionMeta


def find(dataset=ProductionDataset, meta=ProductionMeta):
    url = config.get_config('api', 'host') + "/productions/find"
    parameters = {"dataset": dataset.dict(), "meta": meta.dict()}

    response = requests.request("GET", url, headers=config.headers, json=parameters)

    if response.status_code == 404:
        return None

    if response:
        production = Production(**response.json())

        return production
    else:
        return None
